@@ -32,6 +32,11 @@ type LoginOptions struct {
 
 	Hostname string
 	Token    string
+	JobToken string
+
+	ApiHost     string
+	ApiProtocol string
+	GitProtocol string
 
 	UseKeyring bool
 }
@@ -54,18 +59,33 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 			Authenticate with a GitLab instance.
 			You can pass in a token on standard input by using %[1]s--stdin%[1]s.
 			The minimum required scopes for the token are: %[1]sapi%[1]s, %[1]swrite_repository%[1]s.
+			Configuration and credentials are stored in the global configuration file (Default: %[1]s~/.config/glab-cli/config.yml%[1]s)
 		`, "`"),
 		Example: heredoc.Docf(`
-			# start interactive setup
+			# Start interactive setup
 			$ glab auth login
-			# authenticate against %[1]sgitlab.com%[1]s by reading the token from a file
+
+			# Authenticate against %[1]sgitlab.com%[1]s by reading the token from a file
 			$ glab auth login --stdin < myaccesstoken.txt
-			# authenticate with a self-hosted GitLab instance
+
+			# Authenticate with a self-hosted GitLab instance
 			$ glab auth login --hostname salsa.debian.org
+
+			# Non-interactive setup
+			$ glab auth login --hostname gitlab.example.org --token glpat-xxx --api-host gitlab.example.org:3443 --api-protocol https --git-protocol ssh
+
+			# Non-interactive setup reading token from a file
+			$ glab auth login --hostname gitlab.example.org --api-host gitlab.example.org:3443 --api-protocol https --git-protocol ssh  --stdin < myaccesstoken.txt
+			# non-interactive job token setup
+			$ glab auth login --hostname gitlab.example.org --job-token $CI_JOB_TOKEN
 		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			if !opts.IO.PromptEnabled() && !tokenStdin && opts.Token == "" {
-				return &cmdutils.FlagError{Err: errors.New("'--stdin' or '--token' required when not running interactively.")}
+			if !opts.IO.PromptEnabled() && !tokenStdin && opts.Token == "" && opts.JobToken == "" {
+				return &cmdutils.FlagError{Err: errors.New("'--stdin', '--token', or '--job-token' required when not running interactively.")}
+			}
+
+			if opts.JobToken != "" && (opts.Token != "" || tokenStdin) {
+				return &cmdutils.FlagError{Err: errors.New("specify one of '--job-token' or '--token' or '--stdin'. You cannot use more than one of these at the same time.")}
 			}
 
 			if opts.Token != "" && tokenStdin {
@@ -81,7 +101,7 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 				opts.Token = strings.TrimSpace(string(token))
 			}
 
-			if opts.IO.PromptEnabled() && opts.Token == "" && opts.IO.IsaTTY {
+			if opts.IO.PromptEnabled() && opts.Token == "" && opts.JobToken == "" && opts.IO.IsaTTY {
 				opts.Interactive = true
 			}
 
@@ -95,6 +115,10 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 				opts.Hostname = glinstance.Default()
 			}
 
+			if opts.Interactive && (opts.ApiHost != "" || opts.ApiProtocol != "" || opts.GitProtocol != "") {
+				return &cmdutils.FlagError{Err: errors.New("api-host, api-protocol, and git-protocol can only be used in non-interactive mode.")}
+			}
+
 			if err := loginRun(opts); err != nil {
 				return cmdutils.WrapError(err, "Could not sign in!")
 			}
@@ -105,8 +129,12 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 
 	cmd.Flags().StringVarP(&opts.Hostname, "hostname", "h", "", "The hostname of the GitLab instance to authenticate with.")
 	cmd.Flags().StringVarP(&opts.Token, "token", "t", "", "Your GitLab access token.")
+	cmd.Flags().StringVarP(&opts.JobToken, "job-token", "j", "", "CI job token.")
 	cmd.Flags().BoolVar(&tokenStdin, "stdin", false, "Read token from standard input.")
 	cmd.Flags().BoolVar(&opts.UseKeyring, "use-keyring", false, "Store token in your operating system's keyring.")
+	cmd.Flags().StringVarP(&opts.ApiHost, "api-host", "a", "", "API host url.")
+	cmd.Flags().StringVarP(&opts.ApiProtocol, "api-protocol", "p", "", "API protocol: https, http")
+	cmd.Flags().StringVarP(&opts.GitProtocol, "git-protocol", "g", "", "Git protocol: ssh, https, http")
 
 	return cmd
 }
@@ -134,14 +162,77 @@ func loginRun(opts *LoginOptions) error {
 			if token := config.GetFromEnv("token"); token != "" {
 				fmt.Fprintf(opts.IO.StdErr, "%s One of %s environment variables is set. If you don't want to use it for glab, unset it.\n", c.Yellow("WARNING:"), strings.Join(config.EnvKeyEquivalence("token"), ", "))
 			}
+			if opts.ApiHost != "" {
+				err = cfg.Set(opts.Hostname, "api_host", opts.ApiHost)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.ApiProtocol != "" {
+				err = cfg.Set(opts.Hostname, "api_protocol", opts.ApiProtocol)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.GitProtocol != "" {
+				err = cfg.Set(opts.Hostname, "git_protocol", opts.GitProtocol)
+				if err != nil {
+					return err
+				}
+			}
 
 			return cfg.Write()
 		}
 
 	}
 
+	if opts.JobToken != "" {
+		if opts.Hostname == "" {
+			return errors.New("empty hostname would leak `oauth_token`")
+		}
+
+		if opts.UseKeyring {
+			return keyring.Set("glab:"+opts.Hostname, "", opts.JobToken)
+		} else {
+			err := cfg.Set(opts.Hostname, "job_token", opts.JobToken)
+			if err != nil {
+				return err
+			}
+
+			if opts.ApiHost != "" {
+				err = cfg.Set(opts.Hostname, "api_host", opts.ApiHost)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.ApiProtocol != "" {
+				err = cfg.Set(opts.Hostname, "api_protocol", opts.ApiProtocol)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.GitProtocol != "" {
+				err = cfg.Set(opts.Hostname, "git_protocol", opts.GitProtocol)
+				if err != nil {
+					return err
+				}
+			}
+
+			return cfg.Write()
+		}
+	}
+
 	hostname := opts.Hostname
 	apiHostname := opts.Hostname
+
+	if opts.ApiHost != "" {
+		apiHostname = opts.ApiHost
+	}
+
 	defaultHostname := glinstance.OverridableDefault()
 	isSelfHosted := false
 
@@ -257,7 +348,7 @@ func loginRun(opts *LoginOptions) error {
 	}
 
 	if hostname == "" {
-		return errors.New("empty hostname would leak the token.")
+		return errors.New("empty hostname would leak the token")
 	}
 
 	err = cfg.Set(hostname, "api_host", apiHostname)
@@ -356,6 +447,7 @@ func loginRun(opts *LoginOptions) error {
 	}
 
 	fmt.Fprintf(opts.IO.StdErr, "%s Logged in as %s\n", c.GreenCheck(), c.Bold(username))
+	fmt.Fprintf(opts.IO.StdErr, "%s Configuration saved to %s/%s\n", c.GreenCheck(), config.ConfigDir(), config.ConfigFile())
 
 	return nil
 }
