@@ -2,7 +2,6 @@ package update_kubeconfig
 
 import (
 	"fmt"
-	"net/url"
 	"os"
 	"strconv"
 	"strings"
@@ -12,15 +11,13 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/xanzy/go-gitlab"
 	"gitlab.com/gitlab-org/cli/api"
+	"gitlab.com/gitlab-org/cli/commands/cluster/agent/agentutils"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"k8s.io/client-go/tools/clientcmd"
 	clientcmdapi "k8s.io/client-go/tools/clientcmd/api"
 )
 
 const (
-	kasProxyProtocol = "https"
-	kasProxyEndpoint = "k8s-proxy"
-
 	k8sAuthInfoExecApiVersion = "client.authentication.k8s.io/v1"
 
 	flagAgent      = "agent"
@@ -37,8 +34,8 @@ func NewCmdAgentUpdateKubeconfig(f *cmdutils.Factory) *cobra.Command {
 
 	agentUpdateKubeconfigCmd := &cobra.Command{
 		Use:   "update-kubeconfig [flags]",
-		Short: `Update selected kubeconfig`,
-		Long: heredoc.Doc(`Update selected kubeconfig for use with a GitLab agent for Kubernetes
+		Short: `Update selected kubeconfig.`,
+		Long: heredoc.Doc(`Update selected kubeconfig for use with a GitLab agent for Kubernetes.
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			agentID, err := cmd.Flags().GetInt(flagAgent)
@@ -54,11 +51,11 @@ func NewCmdAgentUpdateKubeconfig(f *cmdutils.Factory) *cobra.Command {
 			return runUpdateKubeconfig(agentID, pathOptions, useContext, f)
 		},
 	}
-	agentUpdateKubeconfigCmd.Flags().IntP(flagAgent, "a", 0, "The numeric agent ID to create the kubeconfig entry for")
+	agentUpdateKubeconfigCmd.Flags().IntP(flagAgent, "a", 0, "The numeric agent ID to create the kubeconfig entry for.")
 	cobra.CheckErr(agentUpdateKubeconfigCmd.MarkFlagRequired(flagAgent))
 	persistentFlags := agentUpdateKubeconfigCmd.PersistentFlags()
-	persistentFlags.StringVar(&pathOptions.LoadingRules.ExplicitPath, pathOptions.ExplicitFileFlag, pathOptions.LoadingRules.ExplicitPath, "Use a particular kubeconfig file")
-	persistentFlags.BoolP(flagUseContext, "u", false, "Use as default context")
+	persistentFlags.StringVar(&pathOptions.LoadingRules.ExplicitPath, pathOptions.ExplicitFileFlag, pathOptions.LoadingRules.ExplicitPath, "Use a particular kubeconfig file.")
+	persistentFlags.BoolP(flagUseContext, "u", false, "Use as default context.")
 
 	return agentUpdateKubeconfigCmd
 }
@@ -80,9 +77,9 @@ func runUpdateKubeconfig(agentID int, configAccess clientcmd.ConfigAccess, useCo
 		return err
 	}
 	if !metadata.KAS.Enabled {
-		return fmt.Errorf("the GitLab agent server for Kubernetes is disabled on %s. Ask your administrator to set it up and enable it", repo.RepoHost())
+		return fmt.Errorf("the GitLab agent server for Kubernetes is disabled on %s. Ask your administrator to enable and configure it.", repo.RepoHost())
 	}
-	kasUrl, err := url.Parse(metadata.KAS.ExternalURL)
+	kasK8SProxyURL, err := agentutils.GetKasK8SProxyURL(metadata)
 	if err != nil {
 		return err
 	}
@@ -114,8 +111,8 @@ func runUpdateKubeconfig(agentID int, configAccess clientcmd.ConfigAccess, useCo
 		startingConfig: *startingConfig,
 		glabExecutable: glabExecutable,
 		glHost:         repo.RepoHost(),
-		glKasUrl:       kasUrl,
 		glUser:         user.Username,
+		kasK8sProxyURL: kasK8SProxyURL,
 		agent:          agent,
 	}
 	config, contextName := updateKubeconfig(params)
@@ -128,10 +125,10 @@ func runUpdateKubeconfig(agentID int, configAccess clientcmd.ConfigAccess, useCo
 		return err
 	}
 
-	fmt.Fprintf(factory.IO.StdOut, "Updated context %s\n", contextName)
+	fmt.Fprintf(factory.IO.StdOut, "Updated context %s.\n", contextName)
 
 	if useContext {
-		fmt.Fprintf(factory.IO.StdOut, "Using context %s\n", contextName)
+		fmt.Fprintf(factory.IO.StdOut, "Using context %s.\n", contextName)
 	}
 	return nil
 }
@@ -140,8 +137,8 @@ type updateKubeconfigParams struct {
 	startingConfig clientcmdapi.Config
 	glabExecutable string
 	glHost         string
-	glKasUrl       *url.URL
 	glUser         string
+	kasK8sProxyURL string
 	agent          *gitlab.Agent
 }
 
@@ -154,7 +151,7 @@ func updateKubeconfig(params updateKubeconfigParams) (clientcmdapi.Config, strin
 	if !exists {
 		startingCluster = clientcmdapi.NewCluster()
 	}
-	config.Clusters[clusterName] = modifyCluster(*startingCluster, constructKasProxyURL(params.glKasUrl))
+	config.Clusters[clusterName] = modifyCluster(*startingCluster, params.kasK8sProxyURL)
 
 	// Updating `users` entry: `kubectl config set-credentials ...`
 	authInfoName := fmt.Sprintf("%s-%d", clusterName, params.agent.ID)
@@ -191,7 +188,7 @@ func modifyAuthInfo(authInfo clientcmdapi.AuthInfo, glabExecutable string, agent
 		Args:            []string{"cluster", "agent", "get-token", "--agent", strconv.Itoa(agentID)},
 		InteractiveMode: clientcmdapi.NeverExecInteractiveMode,
 		InstallHint: heredoc.Doc(`
-			To authenticate to the current cluster, glab is required. 
+			To authenticate to the current cluster, glab is required.
 
 			Follow the installation instructions at https://gitlab.com/gitlab-org/cli#installation.
 		`),
@@ -209,9 +206,3 @@ func modifyContext(ctx clientcmdapi.Context, clusterName, authInfoName string) *
 func sanitizeForKubeconfig(name string) string {
 	return sanitizeReplacer.Replace(name)
 }
-
-func constructKasProxyURL(u *url.URL) string {
-	ku := *u.JoinPath(kasProxyEndpoint)
-	ku.Scheme = kasProxyProtocol
-	return ku.String()
-}
