@@ -79,13 +79,13 @@ type CreateOpts struct {
 	TargetProject *gitlab.Project `json:"target_project,omitempty"`
 }
 
-func NewCmdCreate(f *cmdutils.Factory, runE func(opts *CreateOpts) error) *cobra.Command {
+func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	opts := &CreateOpts{
 		IO:       f.IO,
 		Branch:   f.Branch,
 		Remotes:  f.Remotes,
 		Config:   f.Config,
-		HeadRepo: resolvedHeadRepo(f),
+		HeadRepo: ResolvedHeadRepo(f),
 	}
 
 	mrCreateCmd := &cobra.Command{
@@ -149,10 +149,6 @@ func NewCmdCreate(f *cmdutils.Factory, runE func(opts *CreateOpts) error) *cobra
 				return &cmdutils.FlagError{Err: errors.New("--copy-issue-labels can only be used with --related-issue.")}
 			}
 
-			if runE != nil {
-				return runE(opts)
-			}
-
 			if err := createRun(opts); err != nil {
 				// always save options to file
 				recoverErr := createRecoverSaveFile(opts)
@@ -797,7 +793,7 @@ func generateMRCompareURL(opts *CreateOpts) (string, error) {
 	return u.String(), nil
 }
 
-func resolvedHeadRepo(f *cmdutils.Factory) func() (glrepo.Interface, error) {
+func ResolvedHeadRepo(f *cmdutils.Factory) func() (glrepo.Interface, error) {
 	return func() (glrepo.Interface, error) {
 		httpClient, err := f.HttpClient()
 		if err != nil {
